# ObjectPostImportRequestImportType

The type of data to import. 

## Enum

* `USAGE` (value: `'Usage'`)

* `PAYMENT` (value: `'Payment'`)

* `QUOTE` (value: `'Quote'`)

* `TAXATIONDETAIL` (value: `'TaxationDetail'`)

* `UPDATEACCOUNTINGCODE` (value: `'UpdateAccountingCode'`)

* `CREATEREVENUESCHEDULE` (value: `'CreateRevenueSchedule'`)

* `UPDATEREVENUESCHEDULE` (value: `'UpdateRevenueSchedule'`)

* `DELETEREVENUESCHEDULE` (value: `'DeleteRevenueSchedule'`)

* `IMPORTFXRATE` (value: `'ImportFXRate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


